<?php

namespace Drupal\ckmoon\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for storing district icons settings.
 */
class CkmoonConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'ckmoon.config',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ckmoon_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('ckmoon.config');
    $form['json_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Icomoon Config JSON Path'),
      '#description' => $this->t('Path to the icomoon selection.json file, relative to the default theme.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('json_path'),
    ];
    $form['class_prefix'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Icon class prefix'),
      '#description' => $this->t('A string the icons class names are prefixed with. eg: icon--'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('class_prefix'),
    ];
    $form['menu_icon'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable menu icons.'),
      '#description' => $this->t('Check this box to add a icon select field to menu link edit forms.'),
      '#default_value' => $config->get('menu_icon'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('ckmoon.config')
      ->set('json_path', $form_state->getValue('json_path'))
      ->set('class_prefix', $form_state->getValue('class_prefix'))
      ->set('menu_icon', $form_state->getValue('menu_icon'))
      ->save();
  }

}
